package com.shzg.project.worn.mapper;

import java.util.List;
import com.shzg.project.worn.domain.MqttSensorData;

/**
 * 设备数据Mapper接口
 * 
 * @author shzg
 * @date 2026-04-01
 */
public interface MqttSensorDataMapper 
{
    /**
     * 查询设备数据
     * 
     * @param id 设备数据主键
     * @return 设备数据
     */
    public MqttSensorData selectMqttSensorDataById(Long id);

    /**
     * 查询设备数据列表
     * 
     * @param mqttSensorData 设备数据
     * @return 设备数据集合
     */
    public List<MqttSensorData> selectMqttSensorDataList(MqttSensorData mqttSensorData);

    /**
     * 新增设备数据
     * 
     * @param mqttSensorData 设备数据
     * @return 结果
     */
    public int insertMqttSensorData(MqttSensorData mqttSensorData);

    /**
     * 修改设备数据
     * 
     * @param mqttSensorData 设备数据
     * @return 结果
     */
    public int updateMqttSensorData(MqttSensorData mqttSensorData);

    /**
     * 删除设备数据
     * 
     * @param id 设备数据主键
     * @return 结果
     */
    public int deleteMqttSensorDataById(Long id);

    /**
     * 批量删除设备数据
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteMqttSensorDataByIds(Long[] ids);
}
