package com.shzg.project.worn.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.shzg.common.utils.SecurityUtils;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.shzg.framework.aspectj.lang.annotation.Log;
import com.shzg.framework.aspectj.lang.enums.BusinessType;
import com.shzg.project.worn.domain.MqttSensorData;
import com.shzg.project.worn.service.IMqttSensorDataService;
import com.shzg.framework.web.controller.BaseController;
import com.shzg.framework.web.domain.AjaxResult;
import com.shzg.common.utils.poi.ExcelUtil;
import com.shzg.framework.web.page.TableDataInfo;

/**
 * 设备数据Controller
 * 
 * @author shzg
 * @date 2026-04-01
 */
@RestController
@RequestMapping("/worn/mqttData")
public class MqttSensorDataController extends BaseController
{
    @Autowired
    private IMqttSensorDataService mqttSensorDataService;

    /**
     * 查询设备数据列表
     */
    @PreAuthorize("@ss.hasPermi('worn:mqttData:list')")
    @GetMapping("/list")
    public TableDataInfo list(MqttSensorData mqttSensorData)
    {
        startPage();
        List<MqttSensorData> list = mqttSensorDataService.selectMqttSensorDataList(mqttSensorData);
        return getDataTable(list);
    }

    /**
     * 导出设备数据列表
     */
    @PreAuthorize("@ss.hasPermi('worn:mqttData:export')")
    @Log(title = "设备数据", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, MqttSensorData mqttSensorData)
    {
        List<MqttSensorData> list = mqttSensorDataService.selectMqttSensorDataList(mqttSensorData);
        ExcelUtil<MqttSensorData> util = new ExcelUtil<MqttSensorData>(MqttSensorData.class);
        util.exportExcel(response, list, "设备数据数据");
    }

    /**
     * 获取设备数据详细信息
     */
    @PreAuthorize("@ss.hasPermi('worn:mqttData:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(mqttSensorDataService.selectMqttSensorDataById(id));
    }

    /**
     * 新增设备数据
     */
    @PreAuthorize("@ss.hasPermi('worn:mqttData:add')")
    @Log(title = "设备数据", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody MqttSensorData mqttSensorData)
    {
        return toAjax(mqttSensorDataService.insertMqttSensorData(mqttSensorData));
    }

    /**
     * 修改设备数据
     */
    @PreAuthorize("@ss.hasPermi('worn:mqttData:edit')")
    @Log(title = "设备数据", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody MqttSensorData mqttSensorData)
    {
        return toAjax(mqttSensorDataService.updateMqttSensorData(mqttSensorData));
    }

    /**
     * 删除设备数据
     */
    @PreAuthorize("@ss.hasPermi('worn:mqttData:remove')")
    @Log(title = "设备数据", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(mqttSensorDataService.deleteMqttSensorDataByIds(ids));
    }
}
